==> jc-1.4.0.tar.gz: soot/javaToJimple/ClassLiteralChecker.h <==
// public class soot.javaToJimple.ClassLiteralChecker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 9dee612188a07e6c soot_javaToJimple_ClassLiteralChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_ClassLiteralChecker_H_
#define _JC_soot_javaToJimple_ClassLiteralChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$sub_refs	_jc_soot_javaToJimple_ClassLiteralChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$sub_nonrefs	_jc_soot_javaToJimple_ClassLiteralChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$refs	_jc_soot_javaToJimple_ClassLiteralChecker$refs;
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$nonrefs	_jc_soot_javaToJimple_ClassLiteralChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$object	_jc_soot_javaToJimple_ClassLiteralChecker$object;

typedef const struct _jc_soot_javaToJimple_ClassLiteralChecker$vmethods	_jc_soot_javaToJimple_ClassLiteralChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_ClassLiteralChecker$vtable	_jc_soot_javaToJimple_ClassLiteralChecker$vtable;
typedef const struct _jc_soot_javaToJimple_ClassLiteralChecker$vtype	_jc_soot_javaToJimple_ClassLiteralChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_ClassLiteralChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *);

// Virtual methods
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_ClassLiteralChecker$method$getList$ce57045e15bd2cd8(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *);
extern struct _jc_object *_jc_soot_javaToJimple_ClassLiteralChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_ClassLiteralChecker$method_info$getList$ce57045e15bd2cd8;
extern _jc_method _jc_soot_javaToJimple_ClassLiteralChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_ClassLiteralChecker$vmethods {
	struct _jc_java_util_ArrayList$object	*(*getList$ce57045e15bd2cd8)(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *);
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_ClassLiteralChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_ClassLiteralChecker$vmethods	soot_javaToJimple_ClassLiteralChecker;
};

// Vtype
struct _jc_soot_javaToJimple_ClassLiteralChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_ClassLiteralChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassLiteralChecker$sub_refs {
	struct _jc_java_util_ArrayList$object	*list;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_ClassLiteralChecker$refs {
    _jc_soot_javaToJimple_ClassLiteralChecker$sub_refs	soot_javaToJimple_ClassLiteralChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassLiteralChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_ClassLiteralChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_ClassLiteralChecker$sub_nonrefs	soot_javaToJimple_ClassLiteralChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_ClassLiteralChecker$object {
	_jc_soot_javaToJimple_ClassLiteralChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_ClassLiteralChecker$vtype	*vtype;
	_jc_soot_javaToJimple_ClassLiteralChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_ClassLiteralChecker$vtype _jc_soot_javaToJimple_ClassLiteralChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_ClassLiteralChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_ClassLiteralChecker$class_object;

#endif	/* _JC_soot_javaToJimple_ClassLiteralChecker_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/ClassLiteralChecker.h <==
// public class soot.javaToJimple.ClassLiteralChecker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 534db787197439f0 polyglot_visit_NodeVisitor
// @dep_class 9dee612188a07e6c soot_javaToJimple_ClassLiteralChecker

// header file dependencies
// @dep_header polyglot_visit_NodeVisitor

#include "polyglot/visit/NodeVisitor.h"

#ifndef _JC_soot_javaToJimple_ClassLiteralChecker_H_
#define _JC_soot_javaToJimple_ClassLiteralChecker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_polyglot_ast_Node$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$sub_refs	_jc_soot_javaToJimple_ClassLiteralChecker$sub_refs;
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$sub_nonrefs	_jc_soot_javaToJimple_ClassLiteralChecker$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$refs	_jc_soot_javaToJimple_ClassLiteralChecker$refs;
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$nonrefs	_jc_soot_javaToJimple_ClassLiteralChecker$nonrefs;
typedef struct _jc_soot_javaToJimple_ClassLiteralChecker$object	_jc_soot_javaToJimple_ClassLiteralChecker$object;

typedef const struct _jc_soot_javaToJimple_ClassLiteralChecker$vmethods	_jc_soot_javaToJimple_ClassLiteralChecker$vmethods;
typedef const struct _jc_soot_javaToJimple_ClassLiteralChecker$vtable	_jc_soot_javaToJimple_ClassLiteralChecker$vtable;
typedef const struct _jc_soot_javaToJimple_ClassLiteralChecker$vtype	_jc_soot_javaToJimple_ClassLiteralChecker$vtype;

// Constructors
extern void _jc_soot_javaToJimple_ClassLiteralChecker$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_ArrayList$object *_jc_soot_javaToJimple_ClassLiteralChecker$method$getList$ce57045e15bd2cd8(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_javaToJimple_ClassLiteralChecker$method$leave$cf18a0cab654af63(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_ClassLiteralChecker$method_info$getList$ce57045e15bd2cd8;
extern _jc_method _jc_soot_javaToJimple_ClassLiteralChecker$method_info$leave$cf18a0cab654af63;

// Virtual methods structure
struct _jc_soot_javaToJimple_ClassLiteralChecker$vmethods {
	struct _jc_java_util_ArrayList$object	*(*getList$ce57045e15bd2cd8)(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*leave$cf18a0cab654af63)(_jc_env *, struct _jc_soot_javaToJimple_ClassLiteralChecker$object *, struct _jc_object *, struct _jc_object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_ClassLiteralChecker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_NodeVisitor$vmethods	polyglot_visit_NodeVisitor;
	_jc_soot_javaToJimple_ClassLiteralChecker$vmethods	soot_javaToJimple_ClassLiteralChecker;
};

// Vtype
struct _jc_soot_javaToJimple_ClassLiteralChecker$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_ClassLiteralChecker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassLiteralChecker$sub_refs {
	struct _jc_java_util_ArrayList$object	*list;
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_ClassLiteralChecker$refs {
    _jc_soot_javaToJimple_ClassLiteralChecker$sub_refs	soot_javaToJimple_ClassLiteralChecker;
    _jc_polyglot_visit_NodeVisitor$sub_refs	polyglot_visit_NodeVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_ClassLiteralChecker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_ClassLiteralChecker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_NodeVisitor$sub_nonrefs	polyglot_visit_NodeVisitor;
    _jc_soot_javaToJimple_ClassLiteralChecker$sub_nonrefs	soot_javaToJimple_ClassLiteralChecker;
};

// Object instance structure
struct _jc_soot_javaToJimple_ClassLiteralChecker$object {
	_jc_soot_javaToJimple_ClassLiteralChecker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_ClassLiteralChecker$vtype	*vtype;
	_jc_soot_javaToJimple_ClassLiteralChecker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_ClassLiteralChecker$vtype _jc_soot_javaToJimple_ClassLiteralChecker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_ClassLiteralChecker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_ClassLiteralChecker$class_object;

#endif	/* _JC_soot_javaToJimple_ClassLiteralChecker_H_ */
